==> yanmah2-1.5-noarch.zip: yanmah2-1.5-noarch/coco.php <==
<?php
//YANMAH2 - Yet ANother Mobile Accelerated HatenaHaiku
//(c) 2010 YANMAH2 project
//This program is freesoftware. you can redistribute it and/or modify it under the terms of the [GNU Affero GPL v3](http://www.gnu.org/licenses/agpl.html).
?>
<?php
//coco.php?q=ADDRESS&return=URL
define("HELLO","world");
require_once "product_definitions.php";
require_once "configurable_variables.php";
require_once "common_functions.php";
?>
<?php
require_once 'init_processor.php';
// var_dump($_SESSION);
?>
<?php
$selfcall = htmlspecialchars($_SERVER["PHP_SELF"], ENT_QUOTES);
$safequery = htmlspecialchars($_SERVER["QUERY_STRING"], ENT_QUOTES);
?>
<?php //セキュリティのための前処理。
//NULL バイトの入力を弾く
checkNull($_GET);
checkNull($_POST);
checkNull($_COOKIE);
?>
<?php
if (isset($_GET['image'])){
	$_SESSION['image'] = $_GET['image'];
}
if ($_SESSION['auth'] != TRUE){
// if ($_SESSION['image'] != 'on'){
  $_SESSION = array();
  if (isset($_COOKIE[session_name()])){
	setcookie(session_name(), '', time() - 42000, dirname($_SERVER['SCRIPT_NAME']) . '/', $_SERVER["SERVER_NAME"]);
  }
  session_destroy();
// }
}
?>
<?php
//検索処理
if (isset($_GET['q'])){
}
?>
<?php
if (isset($_GET['q'])){
  $get_q = htmlspecialchars($_GET['q'], ENT_QUOTES);
  $address = urlencode($_GET['q']);
  if (isset($_GET['return'])) $get_return = htmlspecialchars($_GET['return'], ENT_QUOTES);
  $json_url = "http://maps.google.com/maps/api/geocode/json?address={$address}&language=ja&sensor=false";
  $page_head = "{$get_q} でイマココ";
  $self_anchor = "http://{$_SERVER["SERVER_NAME"]}{$selfcall}?q={$get_q}";
  if (isset($_GET['return'])) $self_anchor = $self_anchor.'&amp;return='.$get_return;
  $coco_mode = 'coco-result';
} else {
  if (isset($_GET['return'])) $get_return = htmlspecialchars($_GET['return'], ENT_QUOTES);
  $page_head = "検索してイマココ";
  $self_anchor = "http://{$_SERVER["SERVER_NAME"]}{$selfcall}";
  if (isset($_GET['return'])) $self_anchor = $self_anchor.'?return='.$get_return;
  $coco_mode = 'coco-ready';
}
$self_anchor_possibly_with_pagenum = $self_anchor;
if (isset($_SERVER['QUERY_STRING']) && $_SERVER['QUERY_STRING'] != ''){
  $relog_back = $self_anchor_possibly_with_pagenum . '&log=try';
  $relogin = $self_anchor_possibly_with_pagenum . '&amp;with=haiku&amp;callback='.rawurlencode($relog_back);
} else {
  $relog_back = $self_anchor_possibly_with_pagenum . '?log=try';
  $relogin = $self_anchor_possibly_with_pagenum . '?with=haiku&amp;callback='.rawurlencode($relog_back);
}
if ($_GET['image'] == 'on' || $_SESSION['image'] == 'on'){
	if (preg_match('/^image=on$/u', $_SERVER['QUERY_STRING'])){
		$self_anchor_with_imagemode = $self_anchor_possibly_with_pagenum . '?image=on';
	} elseif (isset($_GET['log']) && preg_match('/^log=(on|off)$/u', $_SERVER['QUERY_STRING'])){
		$self_anchor_with_imagemode = $self_anchor_possibly_with_pagenum . '?image=on';
	} elseif ($_SERVER["QUERY_STRING"] != ""){
		$self_anchor_with_imagemode = $self_anchor_possibly_with_pagenum . '&amp;image=on';
	} else {
		$self_anchor_with_imagemode = $self_anchor_possibly_with_pagenum . '?image=on';
	}
} elseif ($_GET['image'] == 'off' || $_SESSION['image'] == 'off' || $_GET['image'] == '' || $_SESSION['image'] == ''){
	if (preg_match('/^image=off$/u', $_SERVER['QUERY_STRING'])){
		$self_anchor_with_imagemode = $self_anchor_possibly_with_pagenum . '?image=off';
	} elseif (isset($_GET['log']) && preg_match('/^log=(off|on)$/u', $_SERVER['QUERY_STRING'])){
		$self_anchor_with_imagemode = $self_anchor_possibly_with_pagenum . '?image=off';
	} elseif ($_SERVER["QUERY_STRING"] != ""){
		$self_anchor_with_imagemode = $self_anchor_possibly_with_pagenum . '&amp;image=off';
	} else {
		$self_anchor_with_imagemode = $self_anchor_possibly_with_pagenum . '?image=off';
	}
}

?>

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
   "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja" lang="ja">
<head>
	<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
	<meta http-equiv="Content-Style-Type" content="text/css" />
	<meta http-equiv="Content-Script-Type" content="text/javascript" />
	<?php echo "<title>{$page_head} - {$site_name} {$site_name_caption}</title>\n"; ?>
	<link rel="stylesheet" href="<?php echo $style_sheet; ?>" />
	<link rel="icon" href="./favicon.ico" type="image/vnd.microsoft.icon" />
	<link rel="shortcut icon" href="./favicon.ico" type="image/vnd.microsoft.icon" /></head>
<body>
<?php
echoCommonHeader($relogin, $self_anchor_with_imagemode);
echo "<div id=\"header\" class=\"{$coco_mode}\">\n";
echo "<h1 id=\"entries-head\" class=\"head1\">{$page_head}</h1>\n<hr /></div>";
?>
<?php
echo '<div class="coco-search">';
echo '<form method="get" action="" enctype="application/x-www-form-urlencoded" accept-charset="UTF-8">'."\n";
echo '<label for="cocoq">場所:</label>';
echo '<input type="text" id="cocoq" name="q" maxlength="256" value="" title="場所を入力" />';
echo '<input type="hidden" id="toreturn" name="return" value="'.$get_return.'" />';
echo '<input type="submit" id="cocos" value="検索" title="場所を検索" />';
echo '</form>';
echo '</div>';
?>
<?php
if (isset($_GET['q'])){
  echo '<div class="geo-result">';
  $request_url = $json_url;
  $json = getJson($request_url, FALSE);
  if ($json['stat'] !== TRUE){
	$contents = strip_tags($json['stat']);
	echo "<p>Google Geocoding API からデータを取得できなかったような気がします。</p>\n";
	echo "<blockquote>";
	if (isset($json['http'])) echo "HTTP {$json['http']}<br />";
	echo "{$json['stat']}<br />{$contents}</blockquote>\n";
  } else {
	$json_body = $json['body'];
	$contents = json_decode($json_body);
// 	var_dump($contents);
// 	var_dump($contents->status);
	if (!isset($contents->status)){
	  $error = 'json';
// 	  $error_mes = libxml_get_last_error();
	  echo "<p>はわわ、何かのエラーです。</p>";
	  echo "<blockquote>{$json_body}</blockquote>";
// 	  var_dump($error_mes);
	} elseif ($contents->status != 'OK'){
	  $error = 'staus';
	  if ($contents->status == 'ZERO_RESULTS'){
		$error_mes = $contents->status.': 住所が見つかりません。';
	  } elseif ($contents->status == 'OVER_QUERY_LIMIT'){
		$error_mes = $contents->status.': 現在検索できません。';
	  } elseif ($contents->status == 'REQUEST_DENIED'){
		$error_mes = $contents->status.': 要求が成立しませんでした。';
	  } elseif ($contents->status == 'INVALID_REQUEST'){
		$error_mes = $contents->status.': クエリーが不正です。';
	  }
	} else {
	  $error = 'noerror';
	}
	if ($error == 'json'){
	} elseif ($error == 'status'){
	  echo '<p>'.$error_mes.'</p>';
	} else {
	  echo '<ul class="coco-list">';
	  foreach ($contents->results as $val){
		if (isset($_GET['return'])){
		  $parsed_url = parse_url($_GET['return']);
		  if ($parsed_url['query'] != ''){
			$return_base_url = $_GET['return'].'&amp;';
		  } else {
			$return_base_url = $_GET['return'].'?';
		  }
		} else {
		  $return_base_url = "./entries.php?";
		}
		$return_url = $return_base_url."body=".rawurlencode("{$val->formatted_address} にイマココ！\nmap:{$val->geometry->location->lat}:{$val->geometry->location->lng}");
		echo '<li>';
		echo "<p><a href=\"{$return_url}\" class=\"navigation-link\">";
		echo $val->formatted_address;
		echo '</a></p>';
		  echo "<a href=\"http://www.google.co.jp/m/local?site=local&amp;q={$val->geometry->location->lat}%2C{$val->geometry->location->lng}\" class=\"external-link\">";
		if (isset($_SESSION['image']) && $_SESSION['image'] == 'on') {
		  echo "<img src=\"http://maps.google.com/maps/api/staticmap?maptype=mobile&amp;markers={$val->geometry->location->lat}%2C{$val->geometry->location->lng}&amp;sensor=false&amp;size=140x140&amp;zoom=13\" width=\"140\" height=\"140\" />";
		} else {
		  echo "→Google Maps で確認";
		}
		  echo "</a>";
		echo '</li>'."\n";
	  }
	  echo '</ul>';
	}
  }
//   var_dump($error);
  echo "</div>";
}
?>
<p class="credit">位置情報の取得には <a href="<?php echo $mobile_gateway; ?>http://code.google.com/intl/ja/apis/maps/documentation/geocoding/">Google Geocoding API</a> を利用しています。</p>
<hr />
<?php
$navi_paging = FALSE;
$navi_imaging = TRUE;
require 'footer_include.php';
?>
</body>
</html>

==> yanmah2-1.6-noarch.zip: yanmah2-1.6-noarch/coco.php <==
<?php
//YANMAH2 - Yet ANother Mobile Accelerated HatenaHaiku
//(c) 2010 YANMAH2 project
//This program is freesoftware. you can redistribute it and/or modify it under the terms of the [GNU Affero GPL v3](http://www.gnu.org/licenses/agpl.html).
?>
<?php
//coco.php?q=ADDRESS&return=URL
define("HELLO","world");
require_once "product_definitions.php";
require_once "configurable_variables.php";
require_once "common_functions.php";
?>
<?php
require_once 'init_processor.php';
// var_dump($_SESSION);
?>
<?php
$selfcall = htmlspecialchars($_SERVER["PHP_SELF"], ENT_QUOTES);
$safequery = htmlspecialchars($_SERVER["QUERY_STRING"], ENT_QUOTES);
?>
<?php //セキュリティのための前処理。
?>
<?php
if (isset($_GET['image'])){
	$_SESSION['image'] = $_GET['image'];
}
if (!isset($_SESSION['auth']) || $_SESSION['auth'] != TRUE){
// if ($_SESSION['image'] != 'on'){
  $_SESSION = array();
  if (isset($_COOKIE[session_name()])){
	setcookie(session_name(), '', time() - 42000, dirname($_SERVER['SCRIPT_NAME']) . '/', $_SERVER["SERVER_NAME"]);
  }
  session_destroy();
// }
}
?>
<?php
//検索処理
if (isset($_GET['q'])){
}
?>
<?php
if (isset($_GET['q'])){
  $get_q = htmlspecialchars($_GET['q'], ENT_QUOTES);
  $address = urlencode($_GET['q']);
  if (isset($_GET['return'])) $get_return = htmlspecialchars($_GET['return'], ENT_QUOTES);
  $json_url = "http://maps.google.com/maps/api/geocode/json?address={$address}&language=ja&sensor=false";
  $page_head = "{$get_q} でイマココ";
  $self_anchor = "http://{$_SERVER["SERVER_NAME"]}{$selfcall}?q={$get_q}";
  if (isset($_GET['return'])) $self_anchor = $self_anchor.'&amp;return='.$get_return;
  $coco_mode = 'coco-result';
} else {
  if (isset($_GET['return'])) $get_return = htmlspecialchars($_GET['return'], ENT_QUOTES);
  $page_head = "検索してイマココ";
  $self_anchor = "http://{$_SERVER["SERVER_NAME"]}{$selfcall}";
  if (isset($_GET['return'])) $self_anchor = $self_anchor.'?return='.$get_return;
  $coco_mode = 'coco-ready';
}
$self_anchor_possibly_with_pagenum = $self_anchor;
if (isset($_SERVER['QUERY_STRING']) && $_SERVER['QUERY_STRING'] != ''){
  $relog_back = $self_anchor_possibly_with_pagenum . '&log=try';
  $relogin = $self_anchor_possibly_with_pagenum . '&amp;with=haiku&amp;callback='.rawurlencode($relog_back);
} else {
  $relog_back = $self_anchor_possibly_with_pagenum . '?log=try';
  $relogin = $self_anchor_possibly_with_pagenum . '?with=haiku&amp;callback='.rawurlencode($relog_back);
}
if (isset($_GET['image']) && $_GET['image'] == 'on'){
	if (preg_match('/^image=on$/u', $_SERVER['QUERY_STRING'])){
		$self_anchor_with_imagemode = $self_anchor_possibly_with_pagenum . '?image=on';
	} elseif (isset($_GET['log']) && preg_match('/^log=(on|off)$/u', $_SERVER['QUERY_STRING'])){
		$self_anchor_with_imagemode = $self_anchor_possibly_with_pagenum . '?image=on';
	} elseif ($_SERVER["QUERY_STRING"] != ""){
		$self_anchor_with_imagemode = $self_anchor_possibly_with_pagenum . '&amp;image=on';
	} else {
		$self_anchor_with_imagemode = $self_anchor_possibly_with_pagenum . '?image=on';
	}
} else {
	if (preg_match('/^image=off$/u', $_SERVER['QUERY_STRING'])){
		$self_anchor_with_imagemode = $self_anchor_possibly_with_pagenum . '?image=off';
	} elseif (isset($_GET['log']) && preg_match('/^log=(off|on)$/u', $_SERVER['QUERY_STRING'])){
		$self_anchor_with_imagemode = $self_anchor_possibly_with_pagenum . '?image=off';
	} elseif ($_SERVER["QUERY_STRING"] != ""){
		$self_anchor_with_imagemode = $self_anchor_possibly_with_pagenum . '&amp;image=off';
	} else {
		$self_anchor_with_imagemode = $self_anchor_possibly_with_pagenum . '?image=off';
	}
}

?>

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
   "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja" lang="ja">
<head>
	<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
	<meta http-equiv="Content-Style-Type" content="text/css" />
	<meta http-equiv="Content-Script-Type" content="text/javascript" />
	<?php echo "<title>{$page_head} - {$site_name} {$site_name_caption}</title>\n"; ?>
	<link rel="stylesheet" href="<?php echo $style_sheet; ?>" />
	<link rel="icon" href="./favicon.ico" type="image/vnd.microsoft.icon" />
	<link rel="shortcut icon" href="./favicon.ico" type="image/vnd.microsoft.icon" /></head>
<body>
<?php
echoCommonHeader($relogin, $self_anchor_with_imagemode);
echo "<div id=\"header\" class=\"{$coco_mode}\">\n";
echo "<h1 id=\"entries-head\" class=\"head1\">{$page_head}</h1>\n<hr /></div>";
?>
<?php
echo '<div class="coco-search">';
echo '<form method="get" action="" enctype="application/x-www-form-urlencoded" accept-charset="UTF-8">'."\n";
echo '<label for="cocoq">場所:</label>';
echo '<input type="text" id="cocoq" name="q" maxlength="256" value="" title="場所を入力" />';
echo '<input type="hidden" id="toreturn" name="return" value="'.$get_return.'" />';
echo '<input type="submit" id="cocos" value="検索" title="場所を検索" />';
echo '</form>';
echo '</div>';
?>
<?php
if (isset($_GET['q'])){
  echo '<div class="geo-result">';
  $request_url = $json_url;
  $json = getJson($request_url, FALSE);
  if ($json['stat'] !== TRUE){
	$contents = strip_tags($json['stat']);
	echo "<p>Google Geocoding API からデータを取得できなかったような気がします。</p>\n";
	echo "<blockquote>";
	if (isset($json['http'])) echo "HTTP {$json['http']}<br />";
	echo "{$json['stat']}<br />{$contents}</blockquote>\n";
  } else {
	$json_body = $json['body'];
	$contents = json_decode($json_body);
// 	var_dump($contents);
// 	var_dump($contents->status);
	if (!isset($contents->status)){
	  $error = 'json';
// 	  $error_mes = libxml_get_last_error();
	  echo "<p>はわわ、何かのエラーです。</p>";
	  echo "<blockquote>{$json_body}</blockquote>";
// 	  var_dump($error_mes);
	} elseif ($contents->status != 'OK'){
	  $error = 'staus';
	  if ($contents->status == 'ZERO_RESULTS'){
		$error_mes = $contents->status.': 住所が見つかりません。';
	  } elseif ($contents->status == 'OVER_QUERY_LIMIT'){
		$error_mes = $contents->status.': 現在検索できません。';
	  } elseif ($contents->status == 'REQUEST_DENIED'){
		$error_mes = $contents->status.': 要求が成立しませんでした。';
	  } elseif ($contents->status == 'INVALID_REQUEST'){
		$error_mes = $contents->status.': クエリーが不正です。';
	  }
	} else {
	  $error = 'noerror';
	}
	if ($error == 'json'){
	} elseif ($error == 'status'){
	  echo '<p>'.$error_mes.'</p>';
	} else {
	  echo '<ul class="coco-list">';
	  foreach ($contents->results as $val){
		if (isset($_GET['return'])){
		  $parsed_url = parse_url($_GET['return']);
		  if ($parsed_url['query'] != ''){
			$return_base_url = $_GET['return'].'&amp;';
		  } else {
			$return_base_url = $_GET['return'].'?';
		  }
		} else {
		  $return_base_url = "./entries.php?";
		}
		$return_url = $return_base_url."body=".rawurlencode("{$val->formatted_address} にイマココ！\nmap:{$val->geometry->location->lat}:{$val->geometry->location->lng}");
		echo '<li>';
		echo "<p><a href=\"{$return_url}\" class=\"navigation-link\">";
		echo $val->formatted_address;
		echo '</a></p>';
		  echo "<a href=\"http://www.google.co.jp/m/local?site=local&amp;q={$val->geometry->location->lat}%2C{$val->geometry->location->lng}\" class=\"external-link\">";
		if (isset($_SESSION['image']) && $_SESSION['image'] == 'on') {
		  echo "<img src=\"http://maps.google.com/maps/api/staticmap?maptype=mobile&amp;markers={$val->geometry->location->lat}%2C{$val->geometry->location->lng}&amp;sensor=false&amp;size=140x140&amp;zoom=13\" width=\"140\" height=\"140\" />";
		} else {
		  echo "→Google Maps で確認";
		}
		  echo "</a>";
		echo '</li>'."\n";
	  }
	  echo '</ul>';
	}
  }
//   var_dump($error);
  echo "</div>";
}
?>
<p class="credit">位置情報の取得には <a href="<?php echo $mobile_gateway; ?>http://code.google.com/intl/ja/apis/maps/documentation/geocoding/">Google Geocoding API</a> を利用しています。</p>
<hr />
<?php
$navi_paging = FALSE;
$navi_imaging = TRUE;
require 'footer_include.php';
?>
</body>
</html>
